==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/systests/tracing/src/test/java/org/apache/cxf/systest/jaxrs/tracing/brave/IsAnnotationContaining.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxrs.tracing.brave;

import org.hamcrest.Description;
import org.hamcrest.TypeSafeMatcher;
import org.hamcrest.core.IsCollectionContaining;
import zipkin2.Annotation;

public class IsAnnotationContaining extends IsCollectionContaining<Annotation> {
    public IsAnnotationContaining(final String value) {
        super(new TypeSafeMatcher<Annotation>() {
            @Override
            public void describeTo(Description description) {
                description
                    .appendText("annotation with name ")
                    .appendValue(value);
            }

            @Override
            protected boolean matchesSafely(Annotation item) {
                return value.equals(item.value());
            }
        });
    }

    public static IsAnnotationContaining hasItem(final String value) {
        return new IsAnnotationContaining(value);
    }
}

==> apache-cxf-3.6.1-src.tar.gz: apache-cxf-3.6.1-src/systests/tracing/src/test/java/org/apache/cxf/systest/jaxrs/tracing/brave/IsAnnotationContaining.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxrs.tracing.brave;

import org.hamcrest.Description;
import org.hamcrest.TypeSafeMatcher;
import org.hamcrest.core.IsIterableContaining;
import zipkin2.Annotation;

public class IsAnnotationContaining extends IsIterableContaining<Annotation> {
    public IsAnnotationContaining(final String value) {
        super(new TypeSafeMatcher<Annotation>() {
            @Override
            public void describeTo(Description description) {
                description
                    .appendText("annotation with name ")
                    .appendValue(value);
            }

            @Override
            protected boolean matchesSafely(Annotation item) {
                return value.equals(item.value());
            }
        });
    }

    public static IsAnnotationContaining hasItem(final String value) {
        return new IsAnnotationContaining(value);
    }
}
